<div class="gmail_quote">On Thu, Jul 12, 2012 at 3:56 PM, Koen Kooi <span dir="ltr"><<a href="mailto:koen@dominion.thruhere.net" target="_blank">koen@dominion.thruhere.net</a>></span> wrote:<br><blockquote class="gmail_quote" style="margin:0 0 0 .8ex;border-left:1px #ccc solid;padding-left:1ex">
<br>
Op 12 jul. 2012, om 14:26 heeft Andrei Gherzan het volgende geschreven:<br>
<br>
> On Wed, Jul 11, 2012 at 11:53 PM, Saul Wold <<a href="mailto:sgw@linux.intel.com">sgw@linux.intel.com</a>> wrote:<br>
> On 07/11/2012 07:10 AM, Koen Kooi wrote:<br>
> This contains bugfixes from the 5.0.3 and 5.0.4 releases<br>
><br>
> Signed-off-by: Koen Kooi <<a href="mailto:koen@dominion.thruhere.net">koen@dominion.thruhere.net</a>><br>
> ---<br>
> meta/recipes-extended/xz/{<a href="http://xz_5.1.1alpha.bb" target="_blank">xz_5.1.1alpha.bb</a> => <a href="http://xz_5.1.2alpha.bb" target="_blank">xz_5.1.2alpha.bb</a>} | 7 ++-----<br>
> 1 file changed, 2 insertions(+), 5 deletions(-)<br>
> rename meta/recipes-extended/xz/{<a href="http://xz_5.1.1alpha.bb" target="_blank">xz_5.1.1alpha.bb</a> => <a href="http://xz_5.1.2alpha.bb" target="_blank">xz_5.1.2alpha.bb</a>} (86%)<br>
><br>
> diff --git a/meta/recipes-extended/xz/<a href="http://xz_5.1.1alpha.bb" target="_blank">xz_5.1.1alpha.bb</a> b/meta/recipes-extended/xz/<a href="http://xz_5.1.2alpha.bb" target="_blank">xz_5.1.2alpha.bb</a><br>
> similarity index 86%<br>
> rename from meta/recipes-extended/xz/<a href="http://xz_5.1.1alpha.bb" target="_blank">xz_5.1.1alpha.bb</a><br>
> rename to meta/recipes-extended/xz/<a href="http://xz_5.1.2alpha.bb" target="_blank">xz_5.1.2alpha.bb</a><br>
> index 7fa7177..9d68720 100644<br>
> --- a/meta/recipes-extended/xz/<a href="http://xz_5.1.1alpha.bb" target="_blank">xz_5.1.1alpha.bb</a><br>
> +++ b/meta/recipes-extended/xz/<a href="http://xz_5.1.2alpha.bb" target="_blank">xz_5.1.2alpha.bb</a><br>
> @@ -10,11 +10,8 @@ LIC_FILES_CHKSUM = "file://COPYING;md5=c475b6c7dca236740ace4bba553e8e1c \<br>
> file://lib/getopt.c;endline=23;md5=2069b0ee710572c03bb3114e4532cd84 "<br>
><br>
> SRC_URI = "<a href="http://tukaani.org/xz/xz-${PV}.tar.gz" target="_blank">http://tukaani.org/xz/xz-${PV}.tar.gz</a>"<br>
> -<br>
> -SRC_URI[md5sum] = "bb24436fa12780808e1c142980484104"<br>
> -SRC_URI[sha256sum] = "54e59a83690a4a0ec88a7d7c3bdef90c6b196c892a93463863c71c24fe87951a"<br>
> -<br>
> -PR = "r0"<br>
> +SRC_URI[md5sum] = "9bad1e249537ce69b206815cf28ca87b"<br>
> +SRC_URI[sha256sum] = "70e792d2a67cfbb8f2dffd0feab6ca6e5a4a618d65070fb44a367629d1ba94e5"<br>
><br>
> inherit autotools gettext<br>
><br>
><br>
><br>
> How stable is this alpha release? We don't generally take up re-releases, correct?<br>
><br>
><br>
> We already have an alpha release... so another alpha shouldn't be a problem, right? .1a it's a good deal as it implements multithreaded compression and decompression.<br>
<br>
After Andrei's patch for image_types.bbclass goes in I have a follow up patch to enable xz threads (and disable the -e -9) to give a nice speedup for xz images. On my aging core2quad compressing a 4gb image goes from ~22 minutes to ~6.5 minutes with -T4. On my 4c/8t i7 I can get up to a 6x speedup with -T6 or -T8, hyperthreading does a better job than I expected.<br>
<br></blockquote><div> </div><div>I can confirm this. But still, we can hold -e -9 and just add -T4. I think people have 700mb ram to spare while compressing. </div><div><br></div><div>@g</div></div>